@@ -77,6 +77,7 @@ class SampleGenerator:
         self._name = name
         self._field_names: Set[str] = {'label'}
         self._field_types: Dict[str, type] = {}
+        self._fields_default_values: Dict[str, Any] = {}
         self._dataset_fields: Dict[str, Dict[str, Callable]] = {}
         self._custom_methods: Dict[str, Callable] = {}
         self._labels: Set[int] = set()
@@ -91,12 +92,13 @@ class SampleGenerator:
             self._labels = label_set.copy()
             self._field_types['label'] = int
 
-    def add_field(self, field_name: str, field_type: type) -> 'SampleGenerator':
+    def add_field(self, field_name: str, field_type: type, default_value = None) -> 'SampleGenerator':
         """
         Adds a field with the given name and type.
         The field is not considered as a dataset part: it is a simple instance property.
         For each field, getter and setter methods are automatically created.
         If field_type is "numpy.ndarray", other two methods are created: the first generates a DataPipeline to elaborate it, and the second returns this pipeline.
+        In addition, its default value can be specified.
         :raise FieldNameAlreadyExists if the field name already exists
         :param field_name: the name of the field
         :type field_name: str
@@ -111,10 +113,15 @@ class SampleGenerator:
 
         self._field_names.add(field_name)
         self._field_types[field_name] = field_type
+        self._fields_default_values[field_name] = default_value
 
         return self
 
-    def add_dataset_field(self, field_name: str, field_type: type, save_function: Callable[[str, T], NoReturn], load_function: Callable[[str], T]) -> 'SampleGenerator':
+    def add_dataset_field(self, field_name: str,
+                          field_type: type,
+                          save_function: Callable[[str, T], NoReturn],
+                          load_function: Callable[[str], T],
+                          default_value = None) -> 'SampleGenerator':
         """
         Adds a field with the given name and type. The field is considered a part of the dataset,
         so it is saved and load from disk by DatasetDiskManager.
@@ -123,6 +130,7 @@ class SampleGenerator:
         For a dataset field, it is mandatory to specify the functions to save and load it from disk.
         The save function must have the signature: "save_function(path:str, data: data_type) -> NoReturn: ..."
         The load function, instead, must be like this: "load_function(path: str) -> data_type: ..."
+        In addition, its default value can be specified.
         :raise FieldNameAlreadyExists if the field name already exists
         :param field_name: the name of the field
         :type field_name: str
@@ -135,7 +143,7 @@ class SampleGenerator:
         :return: the SampleGenerator instance
         :rtype: SampleGenerator
         """
-        self.add_field(field_name=field_name, field_type=field_type)
+        self.add_field(field_name=field_name, field_type=field_type, default_value=default_value)
         self._dataset_fields[field_name] = {'save_function': save_function, 'load_function': load_function}
         return self
 
@@ -261,7 +269,7 @@ class SampleGenerator:
 
             sample._field_names: Set[str] = self._field_names.copy()
             sample._field_types: Dict[str, type] = self._field_types.copy()
-            sample._field_values: Dict[str, Any] = {field_name: None for field_name in sample._field_names}
+            sample._field_values: Dict[str, Any] = {field_name: field_value for field_name, field_value in self._fields_default_values.items()}
             # The fields with a pipeline must be numpy.ndarray
             sample._pipelines: Dict[str, Union[DataPipeline, None]] = {field_name: None for field_name in sample._field_names if sample._field_types[field_name] == np.ndarray}
             sample._locks: Dict[str, RLock] = {field_name: RLock() for field_name in sample._field_names}
@@ -284,16 +292,14 @@ class SampleGenerator:
             :raise FieldHasIncorrectTypeException if the given value has a wrong type
             :raise AnotherActivePipelineException if the field has an active pipeline (terminate it before setting a new value)
             :param value: the value to be assigned to {1}
-            :type value: {2}
-            :return: the {3} instance
-            :rtype: {4}
+            :return: the {2} instance
             """
             if not isinstance(value, sample._field_types[field_name]):
                 raise FieldHasIncorrectTypeException(field_name)
             sample._field_values[field_name] = value
             return sample
 
-        f.__doc__ = f.__doc__.format(field_name, field_name, field_type.__name__, class_name, class_name)
+        f.__doc__ = f.__doc__.format(field_name, field_name, class_name)
 
         return f
 
@@ -307,11 +313,10 @@ class SampleGenerator:
             If the field is an "numpy.ndarray" and it has an active pipeline, an exception is raised. Terminate it before obtain the fields value.
             :raises AnotherActivePipelineException if the field has an active pipeline
             :return: the value of {1}
-            :rtype: {2}
             """
             return sample._field_values[field_name]
 
-        f.__doc__ = f.__doc__.format(field_name, field_name, field_type.__name__)
+        f.__doc__ = f.__doc__.format(field_name, field_name)
 
         return f
 
